==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video recording is in progress. Close the window?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Open folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Photo</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Switch Cameras</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Close</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Open folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>You don&apos;t have permission to operate this folder</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Close</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Invalid folder</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Open folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Basic</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>File location</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Shoot</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Burst mode</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Self-timer delay</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Output format</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Camera is an image and video capture utility using your PC camera or webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>File not saved</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Save to:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Photo:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Resolution settings</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolution:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Photos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Sound effects</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mirror mode</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Gridlines</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 lines</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 lines</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Maximum resolution:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Stop recording</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stop taking photos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Context menu</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Take photo</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Record video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Stop taking photos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Warm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Cold</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Delay capture</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filters</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Exposure</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>No webcam found</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>The webcam is in use</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Stop recording</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.33.tar.xz: BUILD/src/translations/deepin-camera_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video recording is in progress. Close the window?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Open folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Photo</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Switch Cameras</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Close</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Open folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>You don&apos;t have permission to operate this folder</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Close</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Invalid folder</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Open folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Basic</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>File location</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Shoot</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Burst mode</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Self-timer delay</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Output format</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Camera is an image and video capture utility using your PC camera or webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>File not saved</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Save to:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Photo:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Resolution settings</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolution:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Photos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Sound effects</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mirror mode</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Gridlines</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 lines</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 lines</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Maximum resolution:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Stop recording</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Stop taking photos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Context menu</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Take photo</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Record video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Stop taking photos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>WebM</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Warm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Cold</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Delay capture</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filters</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Exposure</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>No webcam found</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>The webcam is in use</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Stop recording</translation>
    </message>
</context>
</TS>
